@@ -82,7 +82,7 @@ table_init (void)
       float    f;
       uint32_t s;
     } u;
-    u.f = 0.0;
+    u.f = 0.0f;
 
     //u.s[0] = 0;
 
@@ -91,15 +91,15 @@ table_init (void)
         int c;
         int cg;
 
-        if (u.f <= 0.0)
+        if (u.f <= 0.0f)
           {
             c  = 0;
             cg = 0;
           }
         else
           {
-            c  = (u.f * 255.1619) + 0.5;
-            cg = (linear_to_gamma_2_2 (u.f) * 255.1619) + 0.5;
+            c  = (u.f * 255.1619f) + 0.5f;
+            cg = (linear_to_gamma_2_2 (u.f) * 255.1619f) + 0.5f;
             if (cg > 255) cg = 255;
             if (c > 255) c = 255;
           }
@@ -524,10 +524,13 @@ conv_rgba8_rgb8 (const Babl    *conversion,
 #define conv_gamma_rgbAF_gamma_rgbaF   conv_rgbAF_rgbaF
 
 int init (void);
+#include "babl-verify-cpu.inc"
 
 int
 init (void)
 {
+  BABL_VERIFY_CPU();
+  {
   const Babl *rgbaF = babl_format_new (
     babl_model ("RGBA"),
     babl_type ("float"),
@@ -621,5 +624,6 @@ init (void)
   o (rgba8, rgb8);
   o (ga8, rgbaF);
 
+  }
   return 0;
 }
